<?xml version="1.0" encoding="UTF-8"?>
<tileset version="1.4" tiledversion="1.4.1" name="objs" tilewidth="384" tileheight="332" tilecount="62" columns="0">
 <tile id="0">
  <image width="160" height="192" source="alter.png"/>
 </tile>
 <tile id="1">
  <image width="96" height="64" source="blobBlue.png"/>
 </tile>
 <tile id="2">
  <image width="96" height="64" source="blobGreen.png"/>
 </tile>
 <tile id="3">
  <image width="64" height="64" source="blue.png"/>
 </tile>
 <tile id="4">
  <image width="96" height="128" source="bombStroked.png"/>
 </tile>
 <tile id="5">
  <image width="64" height="64" source="castleWall.png"/>
 </tile>
 <tile id="6">
  <image width="384" height="128" source="cloud.png"/>
 </tile>
 <tile id="7">
  <image width="128" height="192" source="column1.png"/>
 </tile>
 <tile id="8">
  <image width="128" height="192" source="column2.png"/>
 </tile>
 <tile id="9">
  <image width="160" height="192" source="doorBlueStroked.png"/>
 </tile>
 <tile id="10">
  <image width="160" height="192" source="doorGreenStroke.png"/>
 </tile>
 <tile id="11">
  <image width="160" height="192" source="doorRedStroked.png"/>
 </tile>
 <tile id="12">
  <image width="160" height="192" source="doorStroked.png"/>
 </tile>
 <tile id="13">
  <image width="64" height="64" source="earthWall.png"/>
 </tile>
 <tile id="14">
  <image width="160" height="192" source="exit.png"/>
 </tile>
 <tile id="15">
  <image width="192" height="192" source="flare.png"/>
 </tile>
 <tile id="16">
  <image width="64" height="64" source="gemBlueStroked.png"/>
 </tile>
 <tile id="17">
  <image width="64" height="64" source="gemRedStroked.png"/>
 </tile>
 <tile id="18">
  <image width="224" height="32" source="grassLarge.png"/>
 </tile>
 <tile id="19">
  <image width="160" height="32" source="grassSmall.png"/>
 </tile>
 <tile id="20">
  <image width="64" height="64" source="grey.png"/>
 </tile>
 <tile id="21">
  <image width="128" height="160" source="hero.png"/>
 </tile>
 <tile id="22">
  <image width="96" height="64" source="keyGreenStroked.png"/>
 </tile>
 <tile id="23">
  <image width="96" height="64" source="keyRedStroked.png"/>
 </tile>
 <tile id="24">
  <image width="96" height="64" source="keyYellowStroked.png"/>
 </tile>
 <tile id="25">
  <image width="192" height="64" source="platform1.png"/>
 </tile>
 <tile id="26">
  <image width="192" height="64" source="platform2.png"/>
 </tile>
 <tile id="27">
  <image width="192" height="64" source="platform3.png"/>
 </tile>
 <tile id="28">
  <image width="192" height="64" source="platform4.png"/>
 </tile>
 <tile id="29">
  <image width="256" height="96" source="platformBase1.png"/>
 </tile>
 <tile id="30">
  <image width="256" height="96" source="platformBase2.png"/>
 </tile>
 <tile id="31">
  <image width="256" height="96" source="platformBase3.png"/>
 </tile>
 <tile id="32">
  <image width="256" height="96" source="platformBase4.png"/>
 </tile>
 <tile id="33">
  <image width="128" height="96" source="platformBlock1.png"/>
 </tile>
 <tile id="34">
  <image width="128" height="96" source="platformBlock2.png"/>
 </tile>
 <tile id="35">
  <image width="128" height="96" source="platformBlock3.png"/>
 </tile>
 <tile id="36">
  <image width="128" height="96" source="platformBlock4.png"/>
 </tile>
 <tile id="37">
  <image width="96" height="64" source="platformConnector1.png"/>
 </tile>
 <tile id="38">
  <image width="96" height="64" source="platformConnector2.png"/>
 </tile>
 <tile id="39">
  <image width="96" height="64" source="platformConnector3.png"/>
 </tile>
 <tile id="40">
  <image width="96" height="64" source="platformConnector4.png"/>
 </tile>
 <tile id="41">
  <image width="96" height="96" source="pushBlock1.png"/>
 </tile>
 <tile id="42">
  <image width="96" height="96" source="pushBlock2.png"/>
 </tile>
 <tile id="43">
  <image width="96" height="96" source="pushBlock3.png"/>
 </tile>
 <tile id="44">
  <image width="64" height="64" source="shadow.png"/>
 </tile>
 <tile id="45">
  <image width="93" height="93" source="shieldStroked.png"/>
 </tile>
 <tile id="46">
  <image width="160" height="128" source="sign.png"/>
 </tile>
 <tile id="48">
  <image width="192" height="96" source="swordStroked.png"/>
 </tile>
 <tile id="49">
  <image width="96" height="96" source="torch.png"/>
 </tile>
 <tile id="50">
  <image width="128" height="32" source="trap.png"/>
 </tile>
 <tile id="51">
  <image width="128" height="96" source="wallDecor1.png"/>
 </tile>
 <tile id="52">
  <image width="128" height="96" source="wallDecor2.png"/>
 </tile>
 <tile id="53">
  <image width="160" height="128" source="wallDecor3.png"/>
 </tile>
 <tile id="54">
  <image width="65" height="64" source="window1.png"/>
 </tile>
 <tile id="55">
  <image width="64" height="64" source="window2.png"/>
 </tile>
 <tile id="56">
  <image width="56" height="59" source="window3.png"/>
 </tile>
 <tile id="57">
  <image width="135" height="115" source="backgroundArch.png"/>
 </tile>
 <tile id="58">
  <image width="380" height="140" source="backgroundMountain.png"/>
 </tile>
 <tile id="59">
  <image width="129" height="332" source="backgroundTower.png"/>
 </tile>
 <tile id="60">
  <image width="109" height="177" source="backgroundTree.png"/>
 </tile>
 <tile id="61">
  <image width="64" height="64" source="earthWall2.png"/>
 </tile>
 <tile id="62">
  <image width="133" height="160" source="skeleton.png"/>
 </tile>
</tileset>
